@@ -1,8 +1,10 @@
 from vkontakte_groups.factories import GroupFactory
 from models import GroupMigration
+from datetime import datetime
 import factory
 
 class GroupMigrationFactory(factory.DjangoModelFactory):
     FACTORY_FOR = GroupMigration
 
-    group = factory.SubFactory(GroupFactory)
\ No newline at end of file
+    group = factory.SubFactory(GroupFactory)
+    time = datetime.now()
\ No newline at end of file
