@@ -18,8 +18,7 @@ class VkontakteGroupsMigrationTest(TestCase):
 
         from vkontakte_groups_statistic.factories import GroupStatFactory
 
-        migration = GroupMigrationFactory()
-        migration.add_members(range(0, 10000))
+        migration = GroupMigrationFactory(members_ids=range(0, 10000))
         migration.update()
         migration.save()
 
@@ -39,13 +38,11 @@ class VkontakteGroupsMigrationTest(TestCase):
 
     def test_comparing_with_previous(self):
 
-        migration1 = GroupMigrationFactory(time=datetime.now() - timedelta(2))
-        migration1.add_members(range(0, 10000))
+        migration1 = GroupMigrationFactory(time=datetime.now() - timedelta(2), members_ids=range(0, 10000))
         migration1.update()
         migration1.save()
 
-        migration2 = GroupMigrationFactory(group=migration1.group, time=datetime.now() - timedelta(1))
-        migration2.add_members(range(0, 9000))
+        migration2 = GroupMigrationFactory(group=migration1.group, time=datetime.now() - timedelta(1), members_ids=range(0, 9000))
         migration2.update()
         migration2.save()
 
@@ -53,8 +50,7 @@ class VkontakteGroupsMigrationTest(TestCase):
         migration2.compare_with_previous()
         self.assertEqual(migration2.hidden, True)
 
-        migration3 = GroupMigrationFactory(group=migration1.group)
-        migration3.add_members(range(0, 9001))
+        migration3 = GroupMigrationFactory(group=migration1.group, members_ids=range(0, 9001))
         migration3.update()
         migration3.save()
 
@@ -65,8 +61,7 @@ class VkontakteGroupsMigrationTest(TestCase):
     def test_m2m_relations(self):
 
         [UserFactory(remote_id=i, fetched=datetime.now()) for i in range(0, 2000)]
-        migration = GroupMigrationFactory()
-        migration.add_members(range(1000, 2000))
+        migration = GroupMigrationFactory(members_ids=list(range(1000, 2000)))
         for i in range(0, 1500):
             migration.group.users.add(User.objects.get(remote_id=i))
 
@@ -80,14 +75,11 @@ class VkontakteGroupsMigrationTest(TestCase):
             UserFactory.create(remote_id=i)
 
         group = GroupFactory.create(remote_id=GROUP_ID)
-        stat1 = GroupMigration.objects.create(group=group)
-        stat2 = GroupMigration.objects.create(group=group)
-        stat3 = GroupMigration.objects.create(group=group)
-        stat1.add_members([1,2,3,4,5])
-        stat2.add_members([1,2,3,4,6])
-        stat3.add_members([1,2,3,5,7])
+        stat1 = GroupMigration.objects.create(group=group, members_ids=[1,2,3,4,5])
         stat1.save_final()
+        stat2 = GroupMigration.objects.create(group=group, members_ids=[1,2,3,4,6])
         stat2.save_final()
+        stat3 = GroupMigration.objects.create(group=group, members_ids=[1,2,3,5,7])
         stat3.save_final()
 
         # difference between stat2 and stat1
@@ -104,8 +96,7 @@ class VkontakteGroupsMigrationTest(TestCase):
         self.assertItemsEqual(stat3.members_entered_ids, [7])
         self.assertItemsEqual(stat3.members_left_ids, [4])
 
-        stat4 = GroupMigration.objects.create(group=group)
-        stat4.add_members([1,2,3,4,6])
+        stat4 = GroupMigration.objects.create(group=group, members_ids=[1,2,3,4,6])
         stat4.save_final()
 
         # difference between stat4 and stat3
@@ -119,8 +110,7 @@ class VkontakteGroupsMigrationTest(TestCase):
         self.assertItemsEqual(stat4.members_entered_ids, [6])
         self.assertItemsEqual(stat4.members_left_ids, [5])
 
-        stat5 = GroupMigration.objects.create(group=group)
-        stat5.add_members([1,2,3,5,7])
+        stat5 = GroupMigration.objects.create(group=group, members_ids=[1,2,3,5,7])
         stat5.save_final()
 
         # difference between stat5 and stat4
